"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResetPassword = void 0;
var react_1 = __importStar(require("react"));
var react_auth_shared_1 = require("@brightlayer-ui/react-auth-shared");
var useQueryString_1 = require("../hooks/useQueryString");
var RoutingContext_1 = require("../contexts/RoutingContext");
var react_router_dom_1 = require("react-router-dom");
var core_1 = require("@material-ui/core");
var components_1 = require("../components");
var constants_1 = require("../constants");
var CheckCircle_1 = __importDefault(require("@material-ui/icons/CheckCircle"));
var Error_1 = __importDefault(require("@material-ui/icons/Error"));
var styles_1 = require("../styles");
var clsx_1 = __importDefault(require("clsx"));
/**
 * Renders a screen stack which handles the reset password flow (deep link from email).
 *
 * @category Component
 */
var ResetPassword = function () {
    var _a;
    var t = react_auth_shared_1.useLanguageLocale().t;
    var history = react_router_dom_1.useHistory();
    var routes = RoutingContext_1.useRoutes().routes;
    var theme = core_1.useTheme();
    var classes = styles_1.useDialogStyles();
    var accountUIState = react_auth_shared_1.useAccountUIState();
    var accountUIActions = react_auth_shared_1.useAccountUIActions();
    var _b = useQueryString_1.useQueryString(), code = _b.code, email = _b.email;
    var passwordRef = react_1.useRef(null);
    var confirmRef = react_1.useRef(null);
    // Local State
    var _c = react_1.useState(''), passwordInput = _c[0], setPasswordInput = _c[1];
    var _d = react_1.useState(''), confirmInput = _d[0], setConfirmInput = _d[1];
    var _e = react_1.useState(false), hasAcknowledgedError = _e[0], setHasAcknowledgedError = _e[1];
    // Network state (verifyResetCode)
    var verifyResetCodeTransit = accountUIState.setPassword.verifyResetCodeTransit;
    var verifyIsInTransit = verifyResetCodeTransit.transitInProgress;
    var validationTransitErrorMessage = verifyResetCodeTransit.transitErrorMessage;
    var verifySuccess = verifyResetCodeTransit.transitSuccess;
    var verifyComplete = verifyResetCodeTransit.transitComplete;
    // Network state (setPassword)
    var setPasswordTransit = accountUIState.setPassword.setPasswordTransit;
    var setPasswordTransitSuccess = setPasswordTransit.transitSuccess;
    var setPasswordIsInTransit = setPasswordTransit.transitInProgress;
    var setPasswordHasTransitError = setPasswordTransit.transitErrorMessage !== null;
    var setPasswordTransitErrorMessage = setPasswordTransit.transitErrorMessage;
    // Reset state on dismissal
    react_1.useEffect(function () { return function () {
        accountUIActions.dispatch(react_auth_shared_1.AccountActions.setPasswordReset());
        accountUIActions.dispatch(react_auth_shared_1.AccountActions.verifyResetCodeReset());
    }; }, // eslint-disable-next-line react-hooks/exhaustive-deps
    []);
    react_1.useEffect(function () {
        if (!verifyIsInTransit && !verifyComplete && code.length > 0) {
            void accountUIActions.actions.verifyResetCode(code, email);
        }
        // eslint-disable-line react-hooks/exhaustive-deps
    }, [verifyIsInTransit, code, email, verifyComplete, accountUIActions.actions]);
    var _f = react_auth_shared_1.useInjectedUIContext().passwordRequirements, passwordRequirements = _f === void 0 ? constants_1.defaultPasswordRequirements(t) : _f;
    var areValidMatchingPasswords = react_1.useCallback(function () {
        for (var i = 0; i < passwordRequirements.length; i++) {
            if (!new RegExp(passwordRequirements[i].regex).test(passwordInput))
                return false;
        }
        return confirmInput === passwordInput;
    }, [passwordRequirements, passwordInput, confirmInput]);
    var updateFields = react_1.useCallback(function (fields) {
        setPasswordInput(fields.password);
        setConfirmInput(fields.confirm);
    }, [setPasswordInput, setConfirmInput]);
    var resetPassword = react_1.useCallback(function (password) {
        void accountUIActions.actions.setPassword(code, password, email);
    }, [accountUIActions, code, email]);
    var canContinue = react_1.useCallback(function () { return areValidMatchingPasswords() && !setPasswordTransit.transitInProgress; }, [areValidMatchingPasswords, setPasswordTransit]);
    var onContinue = react_1.useCallback(function () {
        if (setPasswordTransitSuccess) {
            history.push(routes.LOGIN);
        }
        else {
            resetPassword(passwordInput);
        }
    }, [resetPassword, setPasswordTransitSuccess, passwordInput, history, routes]);
    var getBody = react_1.useCallback(function () {
        return verifySuccess && !verifyIsInTransit ? (setPasswordTransitSuccess ? (react_1.default.createElement(components_1.FinishState, { icon: react_1.default.createElement(CheckCircle_1.default, { color: 'primary', style: { fontSize: 100, marginBottom: theme.spacing(2) } }), title: t('blui:PASSWORD_RESET.SUCCESS_MESSAGE'), description: t('blui:CHANGE_PASSWORD.SUCCESS_MESSAGE') })) : (react_1.default.createElement(components_1.ChangePasswordForm, { passwordRef: passwordRef, confirmRef: confirmRef, passwordLabel: t('blui:LABELS.NEW_PASSWORD'), onPasswordChange: updateFields, onSubmit: canContinue() ? onContinue : undefined }))) : !verifyComplete ? (react_1.default.createElement(react_1.default.Fragment, null)) : (react_1.default.createElement(components_1.FinishState, { icon: react_1.default.createElement(Error_1.default, { color: 'error', style: { fontSize: 100, marginBottom: theme.spacing(2) } }), title: t('blui:MESSAGES.FAILURE'), description: validationTransitErrorMessage }));
    }, [
        t,
        canContinue,
        onContinue,
        theme,
        verifySuccess,
        verifyIsInTransit,
        verifyComplete,
        validationTransitErrorMessage,
        setPasswordTransitSuccess,
        updateFields,
    ]);
    var errorDialog = (react_1.default.createElement(components_1.SimpleDialog, { title: t('blui:MESSAGES.ERROR'), body: t(setPasswordTransitErrorMessage !== null && setPasswordTransitErrorMessage !== void 0 ? setPasswordTransitErrorMessage : ''), open: setPasswordHasTransitError && !hasAcknowledgedError, onClose: function () {
            setHasAcknowledgedError(true);
        } }));
    return (react_1.default.createElement(components_1.BrandedCardContainer, { loading: verifyIsInTransit || setPasswordIsInTransit },
        errorDialog,
        react_1.default.createElement(core_1.CardHeader, { title: react_1.default.createElement(core_1.Typography, { variant: 'h6', style: { fontWeight: 600 } }, t('blui:FORMS.RESET_PASSWORD')), className: classes.dialogTitle }),
        react_1.default.createElement(core_1.CardContent, { className: classes.dialogContent }, getBody()),
        react_1.default.createElement(core_1.Divider, null),
        react_1.default.createElement(core_1.CardActions, { className: classes.dialogActions },
            react_1.default.createElement(core_1.Grid, { container: true, direction: "row", alignItems: "center", justify: "space-between", style: { width: '100%' } },
                !setPasswordTransitSuccess && (react_1.default.createElement(core_1.Button, { variant: "outlined", color: "primary", onClick: function () { return history.push(routes.LOGIN); }, className: classes.dialogButton }, t('blui:ACTIONS.BACK'))),
                verifySuccess && (react_1.default.createElement(core_1.Button, { variant: "contained", disableElevation: true, disabled: !canContinue(), color: "primary", onClick: onContinue, className: clsx_1.default(classes.dialogButton, (_a = {}, _a[classes.fullWidth] = setPasswordTransitSuccess, _a)) }, setPasswordTransitSuccess ? t('blui:ACTIONS.DONE') : t('blui:ACTIONS.OKAY')))))));
};
exports.ResetPassword = ResetPassword;
